Package: hystar
Title: Fit the Hysteretic Threshold Autoregressive Model
Version: 1.0.0
Date: 2023-07-03
Authors@R: c(
    person("Daan", "de Jong", 
           email = "daandejong94@gmail.com", 
           role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-6034-0136")),
    person("European Research Council", role = "fnd")
  )
Maintainer: Daan de Jong <daandejong94@gmail.com>
Description: Estimate parameters of the hysteretic threshold autoregressive
    (HysTAR) model, using conditional least squares.
    In addition, you can generate time series data from the HysTAR model.
    For details, see Li, Guan, Li and Yu (2015) <doi:10.1093/biomet/asv017>.
License: MIT + file LICENSE
URL: https://github.com/daandejongen/hystar/
BugReports: https://github.com/daandejongen/hystar/issues/
Imports: graphics, Rcpp, stats, utils
Suggests: testthat (>= 3.0.0)
LinkingTo: Rcpp
Encoding: UTF-8
RoxygenNote: 7.2.0
NeedsCompilation: yes
Packaged: 2023-07-03 11:16:05 UTC; daandejong
Author: Daan de Jong [aut, cre, cph] (<https://orcid.org/0000-0001-6034-0136>),
  European Research Council [fnd]
Repository: CRAN
Date/Publication: 2023-07-05 14:10:02 UTC
Built: R 4.4.0; aarch64-apple-darwin21.6.0; 2024-04-29 20:06:27 UTC; unix
